set level [getenv LEVEL]
set npu [getenv NPU]
set npd [getenv NPD]
set chip_x [getenv CHIP_X]
set chip_y [getenv CHIP_Y]

analyze -library WORK -format vhdl {../router/fifo.vhdl}
analyze -library WORK -format vhdl {../router/router_types.vhdl}
analyze -library WORK -format vhdl {../arbiter/NthLsbDetector.vhdl}
analyze -library WORK -format vhdl {../encoders/encoder_components.vhdl}
analyze -library WORK -format vhdl {../encoders/encoder8to3.vhdl}
analyze -library WORK -format vhdl {../encoders/encoder16to4.vhdl}
analyze -library WORK -format vhdl {../encoders/encoder32to5.vhdl}
analyze -library WORK -format vhdl {../encoders/encoder_generic.vhdl}
analyze -library WORK -format vhdl {../arbiter/arbiter_unit.vhdl}
analyze -library WORK -format vhdl {../arbiter/arbiter_functions.vhdl}
analyze -library WORK -format vhdl {../router/receiver.vhdl}
analyze -library WORK -format vhdl {../router/sender.vhdl}
analyze -library WORK -format vhdl {../arbiter/parent_arbiter.vhdl}
read_ddc ./results/parent-arbiter-$level-$npu-$npd.ddc
analyze -library WORK -format vhdl {../router/router_components.vhdl}
analyze -library WORK -format vhdl {../router/parent_router.vhdl}
elaborate router -library WORK -parameters "level = $level, num_paths_up = $npu, num_paths_down = $npd, buffer_width = 64, buffer_depth = 4, fifo_ptr_size = 3, chip_x = $chip_x, chip_y = $chip_y"
check_design

create_clock [get_ports clk]  -period 8.0  -waveform {0 4} -name clk

set_clock_uncertainty 0.025  -setup [get_clocks clk]
set_clock_uncertainty 0.025  -hold [get_clocks clk]
set_clock_transition -fall 0.04 [get_clocks clk]
set_clock_transition -rise 0.04 [get_clocks clk]

set_dont_touch clk
set_dont_touch arstN

set_clock_latency -max -source 0.1 [get_clocks clk] 

set_input_delay -max -clock clk  0.05 [get_ports {core_x core_y data_in rcv_reqs send_ack rcv_acks send_reqs data_out}]
set_output_delay -max -clock clk  0.05 [all_outputs]

set_false_path -from [get_ports arstN]

check_timing
compile
report_area > reports/parent-router-$level-$npu-$npd-spl_synth.area
report_power > reports/parent-router-$level-$npu-$npd-spl_synth.power
change_names -hier -rules vhdl 
change_names -hier -rules verilog
write_file -hierarchy -f vhdl    -output "./results/parent-router-$level-$npu-$npd.vhd"
write_file -hierarchy -f verilog -output "./results/parent-router-$level-$npu-$npd.v"
write_sdf  "./results/parent-router-$level-$npu-$npd.sdf"
write -hierarchy -f ddc -output  "./results/parent-router-$level-$npu-$npd.ddc"
